==> react-search-highlighter-1.0.0.tgz: package/webpack.config.js <==
const path = require('path');
const webpack = require('webpack');

module.exports = {
  // context: path.join(__dirname),
  // devtool: 'source-map',
  mode: 'development',
  devServer: {
    // publicPath: '/demo',
    contentBase: __dirname + '/dist',
    port: '9001',
    // host: '0.0.0.0',
    // compress: true,
    // disableHostCheck: true,
    // stats: {
    //   assets: false,
    //   colors: true,
    //   version: false,
    //   hash: false,
    //   timings: true,
    //   chunks: false,
    //   chunkModules: false,
    //   entrypoints: false
    // },
    // headers: {
    //   'Access-Control-Allow-Origin': '*',
    //   'Access-Control-Allow-Methods': 'GET, POST, PUT, DELETE, PATCH, OPTIONS',
    //   'Access-Control-Allow-Headers':
    //     'X-Requested-With, content-type, Authorization'
    // }
  },
  entry: './src/index.js',
  output: {
    path: __dirname + '/dist',
    filename: 'bundle.js'
  },
  // output: {
  //   path: path.join(__dirname, 'demo'),
  //   filename: '[name]-build.js'
  // },
  module: {
    rules: [
      {
        test: /\.s?css/,
        use: [
          'style-loader',
          'css-loader',
          'sass-loader'
        ]
      },
      {
        test: /\.js$/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: [
              "@babel/preset-env",
              '@babel/preset-react',
              {
                plugins: [
                  '@babel/plugin-proposal-class-properties',

                ]
              },
            ]
          }
        }
      },
    ]
  },
  // plugins: [
  //   new webpack.DefinePlugin({
  //     'process.env.NODE_ENV': JSON.stringify('production')
  //   })
  // ]
};

==> react-search-highlighter-1.0.1.tgz: package/webpack.config.js <==
const path = require('path');
const webpack = require('webpack');

module.exports = {
  // context: path.join(__dirname),
  // devtool: 'source-map',
  mode: 'development',
  devServer: {
    // publicPath: '/demo',
    contentBase: __dirname + '/dist',
    port: '9001',
    // host: '0.0.0.0',
    // compress: true,
    // disableHostCheck: true,
    // stats: {
    //   assets: false,
    //   colors: true,
    //   version: false,
    //   hash: false,
    //   timings: true,
    //   chunks: false,
    //   chunkModules: false,
    //   entrypoints: false
    // },
    // headers: {
    //   'Access-Control-Allow-Origin': '*',
    //   'Access-Control-Allow-Methods': 'GET, POST, PUT, DELETE, PATCH, OPTIONS',
    //   'Access-Control-Allow-Headers':
    //     'X-Requested-With, content-type, Authorization'
    // }
  },
  entry: './src/index.js',
  output: {
    path: __dirname + '/dist',
    filename: 'bundle.js'
  },
  // output: {
  //   path: path.join(__dirname, 'demo'),
  //   filename: '[name]-build.js'
  // },
  module: {
    rules: [
      {
        test: /\.s?css/,
        use: [
          'style-loader',
          'css-loader',
          'sass-loader'
        ]
      },
      {
        test: /\.js$/,
        use: {
          loader: 'babel-loader',
          // options: {
            // presets: [
            //   "@babel/preset-env",
            //   '@babel/preset-react',
              // {
              //   plugins: [
              //     '@babel/plugin-proposal-class-properties',
              //   ]
              // },
            // ]
          // }
        }
      },
    ]
  },
  // plugins: [
  //   new webpack.DefinePlugin({
  //     'process.env.NODE_ENV': JSON.stringify('production')
  //   })
  // ]
};
